@@ -2,7 +2,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2007-2018 by Dominique Dumont.
+# This software is Copyright (c) 2007-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -11,7 +11,10 @@
 
 # this file is used by test script
 
-[
+use strict;
+use warnings;
+
+return [
     [
         name    => 'MasterModel::SubSlave2',
         element => [
@@ -132,6 +135,17 @@
                 cargo_type        => 'node',
                 config_class_name => 'MasterModel::SlaveZ',
             },
+            integer_with_warn_if => {
+                type        => 'leaf',
+                value_type  => 'integer',
+                warn_if => {
+                    warn_test => {
+                        code => 'defined $_ && $_ < 9;',
+                        msg  => 'should be greater than 9',
+                        fix  => '$_ = 10;'
+                    }
+                },
+            },
             [qw/lista listb/] => {
                 type       => 'list',
                 cargo_type => 'leaf',
