@@ -1,14 +1,16 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2007-2017 by Dominique Dumont.
+# This software is Copyright (c) 2007-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
+use strict;
+use warnings;
 
-[
+return [
   [
    name => "Itself::WarpOnlyElement",
 
